@@ -1,7 +1,7 @@
 package RPC::Simple::Factory;
 
 use strict;
-use vars qw(@ISA @EXPORT $serverPid);
+use vars qw(@ISA @EXPORT $VERSION $serverPid);
 use Tk ;
 use IO::Socket ;
 use Fcntl ;
@@ -9,6 +9,8 @@ use Data::Dumper ;
 
 require Exporter;
 
+( $VERSION ) = '$Revision: 1.5 $ ' =~ /\$Revision:\s+([^\s]+)/;
+
 @ISA = qw(Exporter);
 @EXPORT= qw(spawn) ;
 # Items to export into callers namespace by default. Note: do not export
